package route

import (
	"youngee_b_api/handler"
	"youngee_b_api/middleware"
	"youngee_b_api/model/http_model"

	"github.com/gin-gonic/gin"
	"github.com/sirupsen/logrus"
	swaggerFiles "github.com/swaggo/files"
	ginSwagger "github.com/swaggo/gin-swagger"
)

func InitRoute(r *gin.Engine) {
	r.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))

	r.POST("/register", handler.WrapRegisterHandler)
	r.POST("/sendCode", handler.WrapSendCodeHandler)
	r.POST("/login", handler.WrapCodeLoginHandler)
	r.GET("/test/ping", func(c *gin.Context) {
		resp := http_model.CommonResponse{
			Status:  0,
			Message: "",
			Data:    "ping",
		}
		c.JSON(200, resp)
	})
	//r.Any("/testDemo", func(c *gin.Context) {
	//	resp := http_model.CommonResponse{
	//		Status:  0,
	//		Message: "",
	//		Data:    "pong",
	//	}
	//	c.JSON(200, resp)
	//	// 注意这里只是debug用的 接口要写成handler形式
	//})
	m := r.Group("/youngee/m")
	{
		m.Use(middleware.LoginAuthMiddleware)
		m.POST("/test", func(c *gin.Context) {
			c.JSON(200, "ok")
			// 注意这里只是debug用的 接口要写成handler形式
			auth := middleware.GetSessionAuth(c)
			logrus.Infof("auth:%+v", auth)
		})
		m.POST("/product/findall", handler.WrapFindAllProductHandler) //查询全部产品
		m.POST("/product/find", handler.WrapFindProductHandler)
		m.POST("/project/create", handler.WrapCreateProjectHandler)
		m.POST("/project/show", handler.WrapShowProjectHandler)
		m.POST("/project/update", handler.WrapUpdateProjectHandler)
		m.POST("/project/delete", handler.WrapDeleteProjectHandler)
		m.POST("/product/create", handler.WrapCreateProductHandler)
		m.POST("/project/list", handler.WrapFullProjectListHandler)
		m.POST("/project/taskList", handler.WrapProjectTaskListHandler)
		m.POST("/project/draftlist", handler.WrapProjectDraftBoxListHandler)      // 草稿箱查询
		m.GET("/project/getCreatingNumber", handler.WrapGetCreatingNumberHandler) // 查询创建中项目数量
		m.POST("/project/changeTaskStatus", handler.WrapProjectChangeTaskStatusHandler)
		m.POST("/pay/paysum", handler.WrapPaySumHandler)
		m.POST("/pay/projectpay", handler.WrapProjectPayHandler)
		m.POST("/enterprise/balance", handler.WrapEnterpriseBalanceHandler)
		//m.POST("/project/recruitstrategycalculate", handler.WrapRecruitStrategyNumberCalculate)
		m.POST("/project/tasklogisticslist", handler.WrapTaskLogisticsListHandler) //物流信息查询
		m.POST("/project/createlogistics", handler.WrapCreateLogisticsHandler)     //创建物流信息
		m.POST("/project/signforreceipt", handler.WrapSignForReceiptHandler)
		m.POST("/project/taskscriptlist", handler.WrapTaskScriptListHandler)               //查询脚本列表
		m.POST("/project/scriptopinion", handler.WrapScriptOpinionHandler)                 //脚本审核意见提交
		m.POST("/project/acceptscript", handler.WrapAcceptScriptHandler)                   //同意脚本
		m.POST("/project/tasksketchlist", handler.WrapTaskSketchListHandler)               //查询初稿列表
		m.POST("/project/findsketchphoto", handler.WrapFindSketchPhotoHandler)             //查询脚本配图和视频demo
		m.POST("/project/sketchopinion", handler.WrapSketchOpinionHandler)                 //脚本审核意见提交
		m.POST("/project/acceptsketch", handler.WrapAcceptSketchHandler)                   //同意脚本
		m.POST("/project/tasklinklist", handler.WrapTaskLinkListHandler)                   //查询链接列表
		m.POST("/project/linkopinion", handler.WrapLinkOpinionHandler)                     //链接审核意见提交
		m.POST("/project/acceptlink", handler.WrapAcceptLinkHandler)                       //同意链接
		m.POST("/project/taskdatalist", handler.WrapTaskDataListHandler)                   //查询数据列表
		m.POST("/project/dataopinion", handler.WrapDataOpinionHandler)                     //数据审核意见提交
		m.POST("/project/acceptdata", handler.WrapAcceptDataHandler)                       //同意数据
		m.POST("/pay/getCodeUrl", handler.WrapGetCodeUrlHandler)                           // 获取微信支付codeURL
		m.POST("/pay/queryOrderByTradeId", handler.WrapQueryOrderByTradeIdHandler)         //根据交易id查询微信是否扫码付款
		m.POST("/pay/rechargeBalance", handler.WrapRechargeBalanceHandler)                 // 支付成功后修改企业余额
		m.POST("/project/feeDetail", handler.WrapFeeDetailHandler)                         // 查看结项的费用明细
		m.POST("/pay/rechargeRecord", handler.WrapRechargeRecordHandler)                   // 查看充值记录
		m.POST("/invoice/addReceiveAddress", handler.WrapAddReceiveAddressHandler)         // 新增收货地址
		m.POST("/invoice/addReceiveInfo", handler.WrapAddReceiveInfoHandler)               // 新增发票信息
		m.GET("/invoice/getReceiveAddress", handler.WrapGetReceiveAddressHandler)          // 获取收货地址
		m.GET("/invoice/getReceiveInfo", handler.WrapGetReceiveInfoHandler)                // 获取发票信息
		m.POST("/invoice/operateReceiveInfo", handler.WrapOperateReceiveInfoHandler)       // 修改或删除发票信息
		m.POST("/invoice/operateReceiveAddress", handler.WrapOperateReceiveAddressHandler) // 修改或删除发票信息
		m.POST("/invoice/addInvoiceRecord", handler.WrapAddInvoiceRecordHandler)           // 修改或删除发票信息
		m.POST("/project/getlinknumberinfo", handler.WrapGetLinkNumberInfoHandler)         //获取链接信息
		m.POST("/project/getlogisticsnumberinfo", handler.WrapGetLogisticsNumberInfoHandler)
		m.POST("/project/getdatanumberinfo", handler.WrapGetDataNumberInfoHandler)
		m.POST("/project/getreviewnumberinfo", handler.WrapGetReviewNumberInfoHandler)
		m.POST("/project/getdefaultnumberinfo", handler.WrapGetDefaultNumberInfoHandler)
		m.POST("/project/taskdefaultreviewlist", handler.WrapTaskDefaultReviewListHandler) // 查询违约列表-脚本、初稿、链接上传违约
		m.POST("/project/taskdefaultdatalist", handler.WrapTaskDefaultDataListHandler)     // 查询违约列表-数据违约
		m.POST("/project/taskteminatinglist", handler.WrapTaskTerminatingListHandler)      // 查询违约列表-解约待处理
		m.POST("/project/taskteminatedlist", handler.WrapTaskTerminatedListHandler)        // 查询违约列表-解约
		m.POST("/project/taskteminate", handler.WrapTaskTerminateHandler)                  // 查询违约列表-解约
		m.POST("/project/getsketchinfo", handler.WrapGetSketchInfoHandler)                 // 获取初稿
		m.POST("/project/taskfinishlist", handler.WrapTaskFinishListHandler)               // 查询违约列表-数据违约
		m.POST("/project/getfinishnumberinfo", handler.WrapGetFinishNumberInfoHandler)
		m.POST("/project/getfinishdata", handler.WrapGetFinishDataHandler)
	}
}
